@@ -1,3 +1,16 @@
+try:
+    from importlib.metadata import version, PackageNotFoundError
+except (ModuleNotFoundError, ImportError):
+    from importlib_metadata import version, PackageNotFoundError
+try:
+    __version__ = version("paramak")
+except PackageNotFoundError:
+    from setuptools_scm import get_version
+
+    __version__ = get_version(root="..", relative_to=__file__)
+
+__all__ = ["__version__"]
+
 from .shape import Shape
 from .reactor import Reactor
 from .utils import rotate, extend, distance_between_two_points, diff_between_angles
@@ -119,3 +132,6 @@ from .parametric_reactors.center_column_study_reactor import CenterColumnStudyRe
 from .parametric_reactors.sparc_paper_2020 import SparcFrom2020PaperDiagram
 from .parametric_reactors.iter_paper_2020 import IterFrom2020PaperDiagram
 from .parametric_reactors.flf_system_code_reactor import FlfSystemCodeReactor
+from .parametric_reactors.negative_triangularity_reactor import (
+    NegativeTriangularityReactor,
+)
