@@ -1,5 +1,5 @@
+from typing import Tuple
 
-from typing import Optional, Tuple
 from paramak import RotateMixedShape
 
 
@@ -54,5 +54,5 @@ class BlanketConstantThicknessArcH(RotateMixedShape):
                 self.inner_upper_point[0] + abs(self.thickness),
                 self.inner_upper_point[1],
                 "straight",
-            )
+            ),
         ]
