@@ -1,5 +1,5 @@
-
 from typing import Optional
+
 from paramak import RotateStraightShape
 
 
@@ -21,10 +21,7 @@ class CuttingWedge(RotateStraightShape):
         **kwargs
     ) -> None:
 
-        super().__init__(
-            rotation_angle=rotation_angle,
-            **kwargs
-        )
+        super().__init__(rotation_angle=rotation_angle, **kwargs)
 
         self.height = height
         self.radius = radius
@@ -51,7 +48,7 @@ class CuttingWedge(RotateStraightShape):
             (0, self.height / 2),
             (self.radius, self.height / 2),
             (self.radius, -self.height / 2),
-            (0, -self.height / 2)
+            (0, -self.height / 2),
         ]
 
         self.points = points
