@@ -1,15 +1,10 @@
-
 from paramak import ITERtypeDivertor
 
 
 class ITERtypeDivertorNoDome(ITERtypeDivertor):
-    """Creates an ITER-like divertor with inner and outer vertical targets
-    """
+    """Creates an ITER-like divertor with inner and outer vertical targets"""
 
-    def __init__(
-        self,
-        **kwargs
-    ):
+    def __init__(self, **kwargs):
 
         super().__init__(
             dome=False,
