@@ -3,7 +3,9 @@ from typing import Optional, Tuple
 from cadquery import Workplane
 
 from paramak import Shape
-from paramak.utils import calculate_wedge_cut
+from paramak.utils import calculate_wedge_cut, patch_workplane
+
+patch_workplane()
 
 
 class ExtrudeCircleShape(Shape):
@@ -102,7 +104,7 @@ class ExtrudeCircleShape(Shape):
 
         self.wire = wire
 
-        solid = wire.extrude(distance=extrusion_distance, both=self.extrude_both)
+        solid = wire.extrude(until=extrusion_distance, both=self.extrude_both)
 
         solid = self.rotate_solid(solid)
         cutting_wedge = calculate_wedge_cut(self)
