@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 
 from paramak import ExtrudeMixedShape
@@ -16,7 +15,12 @@ class ExtrudeSplineShape(ExtrudeMixedShape):
     def __init__(
         self,
         distance: float,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.984, 0.603, 0.6),
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.984,
+            0.603,
+            0.6,
+        ),
+        name: str = "extrudesplineshape",
         **kwargs
     ):
 
@@ -24,5 +28,6 @@ class ExtrudeSplineShape(ExtrudeMixedShape):
             distance=distance,
             connection_type="spline",
             color=color,
+            name=name,
             **kwargs
         )
