@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 
 from paramak import ExtrudeMixedShape
@@ -15,7 +14,12 @@ class ExtrudeStraightShape(ExtrudeMixedShape):
     def __init__(
         self,
         distance: float,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (1.0, 0.498, 0.0),
+        color: Tuple[float, float, float, Optional[float]] = (
+            1.0,
+            0.498,
+            0.0,
+        ),
+        name: str = "extrudestraightshape",
         **kwargs
     ):
 
@@ -23,5 +27,6 @@ class ExtrudeStraightShape(ExtrudeMixedShape):
             distance=distance,
             connection_type="straight",
             color=color,
+            name=name,
             **kwargs
         )
