@@ -1,7 +1,7 @@
-
 from typing import Optional, Tuple
 
 from cadquery import Workplane
+
 from paramak import Shape
 
 
@@ -17,17 +17,17 @@ class RotateCircleShape(Shape):
     def __init__(
         self,
         radius: float,
-        rotation_angle: Optional[float] = 360.0,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (1., 1., 0.6),
+        rotation_angle: float = 360.0,
+        color: Tuple[float, float, float, Optional[float]] = (1.0, 1.0, 0.6),
+        name: str = "rotatecircleshape",
         **kwargs
     ):
 
-        super().__init__(
-            color=color,
-            **kwargs
-        )
+        super().__init__(color=color, name=name, **kwargs)
         self.radius = radius
         self.rotation_angle = rotation_angle
+        self.color = color
+        self.name = name
 
     @property
     def rotation_angle(self):
@@ -48,8 +48,8 @@ class RotateCircleShape(Shape):
     def create_solid(self):
         """Creates a rotated 3d solid using points with circular edges.
 
-           Returns:
-              A CadQuery solid: A 3D solid volume
+        Returns:
+           A CadQuery solid: A 3D solid volume
         """
 
         wire = (
