@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 
 from paramak import RotateMixedShape
@@ -14,8 +13,13 @@ class RotateSplineShape(RotateMixedShape):
 
     def __init__(
         self,
-        rotation_angle: Optional[float] = 360.,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.415, 0.239, 0.603),
+        rotation_angle: float = 360.0,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.415,
+            0.239,
+            0.603,
+        ),
+        name: str = "rotatesplineshape",
         **kwargs
     ):
 
@@ -23,5 +27,6 @@ class RotateSplineShape(RotateMixedShape):
             rotation_angle=rotation_angle,
             color=color,
             connection_type="spline",
+            name=name,
             **kwargs
         )
