@@ -1,4 +1,3 @@
-
 from typing import List, Optional, Tuple
 
 from paramak import SweepMixedShape
@@ -25,10 +24,15 @@ class SweepSplineShape(SweepMixedShape):
     def __init__(
         self,
         path_points: List[Tuple[float, float]],
-        workplane: Optional[str] = "XY",
-        path_workplane: Optional[str] = "XZ",
-        force_cross_section: Optional[bool] = False,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.992, 0.749, 0.435),
+        workplane: str = "XY",
+        path_workplane: str = "XZ",
+        force_cross_section: bool = False,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.992,
+            0.749,
+            0.435,
+        ),
+        name: str = "sweepsplineshape",
         **kwargs
     ):
 
@@ -39,5 +43,6 @@ class SweepSplineShape(SweepMixedShape):
             connection_type="spline",
             force_cross_section=force_cross_section,
             color=color,
+            name=name,
             **kwargs
         )
