@@ -1,5 +1,4 @@
-
-from typing import Optional, List, Tuple
+from typing import List, Optional, Tuple
 
 from paramak import SweepMixedShape
 
@@ -24,10 +23,15 @@ class SweepStraightShape(SweepMixedShape):
     def __init__(
         self,
         path_points: List[Tuple[float, float]],
-        workplane: Optional[str] = "XY",
-        path_workplane: Optional[str] = "XZ",
-        force_cross_section: Optional[bool] = False,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.698, 0.8745, 0.541),
+        workplane: str = "XY",
+        path_workplane: str = "XZ",
+        force_cross_section: bool = False,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.698,
+            0.8745,
+            0.541,
+        ),
+        name: str = "sweepstraightshape",
         **kwargs
     ):
 
@@ -38,5 +42,6 @@ class SweepStraightShape(SweepMixedShape):
             connection_type="straight",
             force_cross_section=force_cross_section,
             color=color,
+            name=name,
             **kwargs
         )
