@@ -1,13 +1,12 @@
-import collections
-import json
-from collections import Counter
+import os
+import tempfile
 from collections.abc import Iterable
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
 
 import cadquery as cq
 import matplotlib.pyplot as plt
-from cadquery import Compound, exporters
+from cadquery import exporters
 
 import paramak
 from paramak.utils import _replace, get_hash
@@ -59,7 +58,6 @@ class Reactor:
 
         self.graveyard = None
         self.solid = None
-
         self.reactor_hash_value = None
 
     @property
@@ -183,27 +181,27 @@ class Reactor:
 
         return all_names
 
-    def show(self, default_edgecolor: Tuple[float, float, float] = (0, 0, 0)):
+    def show(self, **kwargs):
         """Shows / renders the CadQuery the 3d object in Jupyter Lab. Imports
-        show from jupyter_cadquery.cadquery and returns show(Reactor.solid)
+        show from jupyter_cadquery and returns show(Reactor.solid, kwargs)
 
         Args:
-            default_edgecolor: the color to use for the edges, passed to
-                jupyter_cadquery.cadquery show. Tuple of three values expected
-                individual values in the tuple should be floats between 0. and
-                1.
+            kwargs: keyword arguments passed to jupyter-cadquery show()
+                function. See https://github.com/bernhard-42/jupyter-cadquery#usage
+                for more details on acceptable keywords
+
 
         Returns:
-            jupyter_cadquery.cadquery.show object
+            jupyter_cadquery show object
         """
 
         try:
-            from jupyter_cadquery.cadquery import Part, PartGroup, show
+            from jupyter_cadquery import Part, PartGroup, show
         except ImportError:
             msg = (
-                "To use Reactor.show() you must install jupyter_cadquery. To"
-                'install jupyter_cadquery type "pip install jupyter_cadquery"'
-                " in the terminal"
+                "To use Reactor.show() you must install jupyter_cadquery version "
+                '3.0.0 or above. To install jupyter_cadquery type "pip install '
+                'jupyter_cadquery" in the terminal'
             )
             raise ImportError(msg)
 
@@ -216,7 +214,6 @@ class Reactor:
                 name = shape_or_compound.name
 
             scaled_color = [int(i * 255) for i in shape_or_compound.color[0:3]]
-            scaled_edge_color = [int(i * 255) for i in default_edgecolor[0:3]]
             if isinstance(
                 shape_or_compound.solid,
                 (cq.occ_impl.shapes.Shape, cq.occ_impl.shapes.Compound),
@@ -232,7 +229,124 @@ class Reactor:
                     )
                 )
 
-        return show(PartGroup(parts), default_edgecolor=scaled_edge_color)
+        return show(PartGroup(parts), **kwargs)
+
+    def export_dagmc_h5m(
+        self,
+        filename: str = "dagmc.h5m",
+        min_mesh_size: float = 5,
+        max_mesh_size: float = 20,
+        exclude: List[str] = None,
+        verbose=False,
+        volume_atol=0.000001,
+        center_atol=0.000001,
+        bounding_box_atol=0.000001,
+    ) -> str:
+        """Export a DAGMC compatible h5m file for use in neutronics simulations.
+        This method makes use of Gmsh to create a surface mesh of the geometry.
+        MOAB is used to convert the meshed geometry into a h5m with parts tagged by
+        using the reactor.shape_and_components.name properties. You will need
+        Gmsh installed and MOAB installed to use this function. Acceptable
+        tolerances may need increasing to match reactor parts with the parts
+        in the intermediate Brep file produced during the process
+
+        Args:
+            filename: the filename of the DAGMC h5m file to write
+            min_mesh_size: the minimum mesh element size to use in Gmsh. Passed
+                into gmsh.option.setNumber("Mesh.MeshSizeMin", min_mesh_size)
+            max_mesh_size: the maximum mesh element size to use in Gmsh. Passed
+                into gmsh.option.setNumber("Mesh.MeshSizeMax", max_mesh_size)
+            exclude: A list of shape names to not include in the exported
+                geometry. 'plasma' is often excluded as not many neutron
+                interactions occur within a low density plasma.
+            volume_atol: the absolute volume tolerance to allow when matching
+                parts in the intermediate brep file with the cadquery parts
+            center_atol: the absolute center coordinates tolerance to allow
+                when matching parts in the intermediate brep file with the
+                cadquery parts
+            bounding_box_atol: the absolute volume tolerance to allow when
+                matching parts in the intermediate brep file with the cadquery
+                parts
+        """
+
+        # a local import is used here as these packages need CQ master to work
+        from brep_to_h5m import brep_to_h5m
+        import brep_part_finder as bpf
+
+        tmp_brep_filename = tempfile.mkstemp(suffix=".brep", prefix="paramak_")[1]
+
+        # saves the reactor as a Brep file with merged surfaces
+        self.export_brep(tmp_brep_filename)
+
+        # brep file is imported
+        brep_file_part_properties = bpf.get_brep_part_properties(tmp_brep_filename)
+
+        if verbose:
+            print("brep_file_part_properties", brep_file_part_properties)
+
+        shape_properties = {}
+        for shape_or_compound in self.shapes_and_components:
+            sub_solid_descriptions = []
+
+            # checks if the solid is a cq.Compound or not
+            if isinstance(shape_or_compound.solid, cq.occ_impl.shapes.Compound):
+                iterable_solids = shape_or_compound.solid.Solids()
+            else:
+                iterable_solids = shape_or_compound.solid.val().Solids()
+
+            for sub_solid in iterable_solids:
+                part_bb = sub_solid.BoundingBox()
+                part_center = sub_solid.Center()
+                sub_solid_description = {
+                    "volume": sub_solid.Volume(),
+                    "center": (part_center.x, part_center.y, part_center.z),
+                    "bounding_box": (
+                        (part_bb.xmin, part_bb.ymin, part_bb.zmin),
+                        (part_bb.xmax, part_bb.ymax, part_bb.zmax),
+                    ),
+                }
+                sub_solid_descriptions.append(sub_solid_description)
+            shape_properties[shape_or_compound.name] = sub_solid_descriptions
+
+        if verbose:
+            print("shape_properties", shape_properties)
+
+        # request to find part ids that are mixed up in the Brep file
+        # using the volume, center, bounding box that we know about when creating the
+        # CAD geometry in the first place
+        key_and_part_id = bpf.get_dict_of_part_ids(
+            brep_part_properties=brep_file_part_properties,
+            shape_properties=shape_properties,
+            volume_atol=volume_atol,
+            center_atol=center_atol,
+            bounding_box_atol=bounding_box_atol,
+        )
+
+        if verbose:
+            print(f"key_and_part_id={key_and_part_id}")
+
+        # allows components like the plasma to be removed
+        if isinstance(exclude, Iterable):
+            for name_to_remove in exclude:
+                key_and_part_id = {
+                    key: val
+                    for key, val in key_and_part_id.items()
+                    if val != name_to_remove
+                }
+
+        brep_to_h5m(
+            brep_filename=tmp_brep_filename,
+            volumes_with_tags=key_and_part_id,
+            h5m_filename=filename,
+            min_mesh_size=min_mesh_size,
+            max_mesh_size=max_mesh_size,
+            delete_intermediate_stl_files=True,
+        )
+
+        # temporary brep is deleted
+        os.remove(tmp_brep_filename)
+
+        return filename
 
     def export_stp(
         self,
@@ -340,7 +454,11 @@ class Reactor:
             bldr = OCP.BOPAlgo.BOPAlgo_Splitter()
 
             for shape in self.shapes_and_components:
-                bldr.AddArgument(shape.solid.val().wrapped)
+                # checks if solid is a compound as .val() is not needed for compunds
+                if isinstance(shape.solid, cq.occ_impl.shapes.Compound):
+                    bldr.AddArgument(shape.solid.wrapped)
+                else:
+                    bldr.AddArgument(shape.solid.val().wrapped)
 
             bldr.SetNonDestructive(True)
 
@@ -701,27 +819,24 @@ class Reactor:
         return str(path_filename)
 
     def export_html_3d(
-        self,
-        filename: Optional[str] = "reactor_3d.html",
+        self, filename: Optional[str] = "reactor_3d.html", **kwargs
     ) -> Optional[str]:
         """Saves an interactive 3d html view of the Reactor to a html file.
 
         Args:
             filename: the filename used to save the html graph. Defaults to
                 reactor_3d.html
+            kwargs: keyword arguments passed to jupyter-cadquery show()
+                function. See https://github.com/bernhard-42/jupyter-cadquery#usage
+                for more details on acceptable keywords
 
         Returns:
             str: filename of the created html file
         """
 
-        from ipywidgets.embed import embed_minimal_html
+        view = self.show(**kwargs)
 
-        view = self.show()
-
-        if view is None:
-            return None
-
-        embed_minimal_html(filename, views=[view.cq_view.renderer], title="Renderer")
+        view.export_html(filename)
 
         return filename
 
