@@ -1,6 +1,6 @@
-import json
 import numbers
-import warnings
+import os
+import tempfile
 from collections.abc import Iterable
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
@@ -537,27 +537,26 @@ class Shape:
         result = importers.importStep(filename)
         self.solid = result
 
-    def show(self, default_edgecolor: Tuple[float, float, float] = (0, 0, 0)):
+    def show(self, **kwargs):
         """Shows / renders the CadQuery the 3d object in Jupyter Lab. Imports
-        show from jupyter_cadquery.cadquery and returns show(Shape.solid)
+        show from jupyter_cadquery and returns show(Shape.solid, kwargs)
 
         Args:
-            default_edgecolor: the color to use for the edges, passed to
-                jupyter_cadquery.cadquery show. Tuple of three values expected
-                individual values in the tuple should be floats between 0. and
-                1.
+            kwargs: keyword arguments passed to jupyter-cadquery show()
+                function. See https://github.com/bernhard-42/jupyter-cadquery#usage
+                for more details on acceptable keywords
 
         Returns:
-            jupyter_cadquery.cadquery.show object
+            jupyter_cadquery show object
         """
 
         try:
-            from jupyter_cadquery.cadquery import Part, PartGroup, show
+            from jupyter_cadquery import Part, PartGroup, show
         except ImportError:
             msg = (
-                "To use Shape.show() you must install jupyter_cadquery. To"
-                'install jupyter_cadquery type "pip install jupyter_cadquery"'
-                " in the terminal"
+                "To use Reactor.show() you must install jupyter_cadquery version "
+                '3.0.0 or above. To install jupyter_cadquery type "pip install '
+                'jupyter_cadquery" in the terminal'
             )
             raise ImportError(msg)
 
@@ -568,7 +567,6 @@ class Shape:
             name = self.name
 
         scaled_color = [int(i * 255) for i in self.color[0:3]]
-        scaled_edge_color = [int(i * 255) for i in default_edgecolor[0:3]]
         if isinstance(self.solid, (shapes.Shape, shapes.Compound)):
             for i, solid in enumerate(self.solid.Solids()):
                 parts.append(
@@ -584,7 +582,7 @@ class Shape:
                 )
             )
 
-        return show(PartGroup(parts), default_edgecolor=scaled_edge_color)
+        return show(PartGroup(parts), **kwargs)
 
     def create_solid(self) -> Workplane:
         solid = None
@@ -847,6 +845,50 @@ class Shape:
 
         return str(path_filename)
 
+    def export_dagmc_h5m(
+        self,
+        filename: str = "dagmc.h5m",
+        min_mesh_size: float = 10,
+        max_mesh_size: float = 20,
+    ) -> str:
+        """Export a DAGMC compatible h5m file for use in neutronics simulations.
+        This method makes use of Gmsh to create a surface mesh of the geometry.
+        MOAB is used to convert the meshed geometry into a h5m with parts tagged by
+        using the reactor.shape_and_components.name properties. You will need
+        Gmsh installed and MOAB installed to use this function.
+
+        Args:
+            filename: the filename of the DAGMC h5m file to write
+            min_mesh_size: the minimum mesh element size to use in Gmsh. Passed
+                into gmsh.option.setNumber("Mesh.MeshSizeMin", min_mesh_size)
+            max_mesh_size: the maximum mesh element size to use in Gmsh. Passed
+                into gmsh.option.setNumber("Mesh.MeshSizeMax", max_mesh_size)
+        """
+
+        from brep_to_h5m import brep_to_h5m
+
+        tmp_brep_filename = tempfile.mkstemp(suffix=".brep", prefix="paramak_")[1]
+
+        # saves the reactor as a Brep file with merged surfaces
+        self.export_brep(tmp_brep_filename)
+
+        volumes_with_tags = {}
+        for counter, _ in enumerate(self.solid.val().Solids(), 1):
+            volumes_with_tags[counter] = f"mat_{self.name}"
+
+        brep_to_h5m(
+            brep_filename=tmp_brep_filename,
+            volumes_with_tags=volumes_with_tags,
+            h5m_filename=filename,
+            min_mesh_size=min_mesh_size,
+            max_mesh_size=max_mesh_size,
+        )
+
+        # temporary brep is deleted
+        os.remove(tmp_brep_filename)
+
+        return filename
+
     def export_stp(
         self,
         filename: str,
@@ -987,28 +1029,23 @@ class Shape:
 
         return str(path_filename)
 
-    def export_html_3d(
-        self,
-        filename: Optional[str] = "shape_3d.html",
-    ):
+    def export_html_3d(self, filename: Optional[str] = "shape_3d.html", **kwargs):
         """Saves an interactive 3d html view of the Shape to a html file.
 
         Args:
             filename: the filename used to save the html graph. Defaults to
                 shape_3d.html
+            kwargs: keyword arguments passed to jupyter-cadquery show()
+                function. See https://github.com/bernhard-42/jupyter-cadquery#usage
+                for more details on acceptable keywords
 
         Returns:
             str: filename of the created html file
         """
 
-        from ipywidgets.embed import embed_minimal_html
+        view = self.show(**kwargs)
 
-        view = self.show()
-
-        if view is None:
-            return None
-
-        embed_minimal_html(filename, views=[view.cq_view.renderer], title="Renderer")
+        view.export_html(filename)
 
         return filename
 
@@ -1331,7 +1368,7 @@ class Shape:
         self.processed_points = new_points
         return new_points
 
-    def volume(self, split_compounds=False) -> Union[float, List[float]]:
+    def volume(self, split_compounds: bool = False) -> Union[float, List[float]]:
         """Get the total volume of the Shape.
 
         Args:
