@@ -1,11 +1,9 @@
-import json
 import os
 import unittest
 from pathlib import Path
 
 import pytest
 from cadquery import Plane
-from numpy.testing._private.utils import assert_
 
 import paramak
 
@@ -77,12 +75,6 @@ class TestShape(unittest.TestCase):
 
         self.assertRaises(ValueError, incorrect_graveyard)
 
-    def test_show_runs_without_error(self):
-        """checks that the jupyter notebook (with cadquery addition) runs
-        without error."""
-
-        self.test_extrude_mixed_shape.show()
-
     def test_make_graveyard_offset(self):
         """checks that the graveyard can be exported with the correct default
         parameters and that these parameters can be changed"""
@@ -383,19 +375,6 @@ class TestShape(unittest.TestCase):
 
         self.assertRaises(ValueError, export)
 
-    def test_export_3d_html(self):
-        """Checks the 3d html file is exported by the export_html_3d method
-        with the correct filename"""
-
-        test_shape = paramak.RotateStraightShape(
-            points=[(0, 0), (0, 20), (20, 20), (20, 0)], rotation_angle=360
-        )
-
-        os.system("rm filename.html")
-        filename = test_shape.export_html_3d("filename.html")
-        if filename is not None:
-            assert Path("filename.html").exists() is True
-
     def test_invalid_stp_filename(self):
         """Checks ValueError is raised when invalid stp filenames are used."""
 
